==> react-native-ui-view-0.1.1.tgz: package/esm/components/ActionSheet/index.js <==
import React from 'react';
import { StyleSheet, View, Text, Image } from 'react-native';
import Touchable from '../Touchable';
import { Theme } from '../Styles/theme';
import Icon from '../Icon';
import Popup from '../Popup';
const ActionSheet = props => {
    const { visible, cancelText = '取消', actions, showCheckStatus = false, checkSize = 24, checkColor = Theme.colorTextParagraph, checkIndex, onClose, onClickItem, } = props;
    return (React.createElement(Popup, { visible: visible, barStyle: "light-content", closeOnClickOverlay: true, onClose: onClose },
        React.createElement(View, { style: styles.container },
            actions.map((item, index) => {
                const { name, icon, iconSize = 24, subName, color, fontSize, disabled } = item;
                const showIcon = !!icon;
                const style = {};
                color && (style.color = color);
                fontSize && (style.fontSize = fontSize);
                return (React.createElement(Touchable, { key: index, underlayColor: Theme.fillBody, onPress: () => onClickItem(index), disabled: disabled, style: [styles.sheetItem, index === 0 && styles.noBorder] },
                    React.createElement(React.Fragment, null,
                        React.createElement(View, { style: [styles.main, showCheckStatus && styles.mainInLeft] }, showCheckStatus ? (React.createElement(React.Fragment, null,
                            React.createElement(View, { style: styles.checkWrap },
                                !!showIcon && icon && (React.createElement(Image, { source: icon, style: [styles.icon, { width: iconSize, height: iconSize }] })),
                                React.createElement(Text, { style: [styles.sheetText, disabled && styles.disabledText, style] }, name)),
                            index === checkIndex && React.createElement(Icon, { name: "check", size: checkSize, color: checkColor }))) : (React.createElement(React.Fragment, null,
                            !!showIcon && icon && (React.createElement(Image, { source: icon, style: [styles.icon, { width: iconSize, height: iconSize }] })),
                            React.createElement(Text, { style: [styles.sheetText, disabled && styles.disabledText, style] }, name)))),
                        !!subName && (React.createElement(View, { style: [styles.sub, showCheckStatus && styles.mainInLeft] },
                            React.createElement(Text, { style: styles.subText }, subName))))));
            }),
            React.createElement(Touchable, { underlayColor: Theme.fillBody, onPress: onClose, style: [styles.sheetItem, styles.noBorder, styles.cancel] },
                React.createElement(Text, { style: styles.sheetText }, cancelText)))));
};
const styles = StyleSheet.create({
    container: {
        backgroundColor: Theme.fillBody,
        borderTopLeftRadius: 10,
        borderTopRightRadius: 10,
        overflow: 'hidden',
    },
    sheetItem: {
        justifyContent: 'center',
        borderTopWidth: 0.5,
        paddingVertical: 15,
        backgroundColor: Theme.fillBase,
        borderTopColor: Theme.borderColor,
    },
    noBorder: {
        borderTopWidth: 0,
    },
    sheetText: {
        fontSize: 15,
        color: Theme.colorTextBase,
    },
    disabledText: {
        color: Theme.colorTextDisabled,
    },
    main: {
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        paddingHorizontal: 15,
    },
    mainInLeft: {
        justifyContent: 'space-between',
    },
    checkWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    sub: {
        marginTop: 4,
        justifyContent: 'center',
        paddingHorizontal: 15,
    },
    subInLeft: {
        justifyContent: 'flex-start',
    },
    icon: {
        marginRight: 24,
    },
    subText: {
        fontSize: 12,
        color: Theme.colorTextSecondary,
    },
    cancel: {
        marginTop: 8,
        alignItems: 'center',
    },
});
export default ActionSheet;

==> react-native-ui-view-0.2.0.tgz: package/esm/components/ActionSheet/index.js <==
import React from 'react';
import { StyleSheet, View, Text, Image } from 'react-native';
import Touchable from '../Touchable';
import { Theme } from '../Styles/theme';
import Icon from '../Icon';
import Popup from '../Popup';
const ActionSheet = props => {
    const { visible, cancelText = '取消', actions, align = 'center', showCheckStatus = false, checkSize = 24, checkColor = '#7f7f7f', checkIndex, iconCircular = false, onClose, onClickItem, } = props;
    const mainStyle = [];
    if (showCheckStatus) {
        mainStyle.push(styles.mainBetween);
    }
    else if (align === 'left') {
        mainStyle.push(styles.mainInLeft);
    }
    else if (align === 'right') {
        mainStyle.push(styles.mainInRight);
    }
    return (React.createElement(Popup, { visible: visible, barStyle: "light-content", closeOnClickOverlay: true, onClose: onClose },
        React.createElement(View, { style: styles.container },
            actions.map((item, index) => {
                const { name, icon, iconSize = 24, subName, color, fontSize, disabled } = item;
                const showIcon = !!icon;
                const style = {};
                color && (style.color = color);
                fontSize && (style.fontSize = fontSize);
                const iconAndText = (React.createElement(React.Fragment, null,
                    !!showIcon && icon && (React.createElement(Image, { source: icon, style: [
                            styles.icon,
                            { width: iconSize, height: iconSize },
                            iconCircular && { borderRadius: iconSize / 2 },
                        ], resizeMethod: "scale", resizeMode: "contain" })),
                    React.createElement(Text, { style: [styles.sheetText, disabled && styles.disabledText, style] }, name)));
                return (React.createElement(Touchable, { key: index, underlayColor: Theme.fillBody, onPress: () => onClickItem(index), disabled: disabled, style: [styles.sheetItem, index === 0 && styles.noBorder] },
                    React.createElement(React.Fragment, null,
                        React.createElement(View, { style: [styles.main, ...mainStyle] }, showCheckStatus ? (React.createElement(React.Fragment, null,
                            React.createElement(View, { style: styles.checkWrap }, iconAndText),
                            index === checkIndex && React.createElement(Icon, { name: "check", size: checkSize, color: checkColor }))) : (iconAndText)),
                        !!subName && (React.createElement(View, { style: [styles.sub, showCheckStatus && styles.mainInLeft] },
                            React.createElement(Text, { style: styles.subText }, subName))))));
            }),
            React.createElement(Touchable, { underlayColor: Theme.fillBody, onPress: onClose, style: [styles.sheetItem, styles.noBorder, styles.cancel] },
                React.createElement(Text, { style: styles.sheetText }, cancelText)))));
};
const styles = StyleSheet.create({
    container: {
        backgroundColor: Theme.fillBody,
        borderTopLeftRadius: 10,
        borderTopRightRadius: 10,
        overflow: 'hidden',
    },
    sheetItem: {
        justifyContent: 'center',
        borderTopWidth: 0.5,
        paddingVertical: 15,
        backgroundColor: Theme.fillBase,
        borderTopColor: Theme.borderColor,
    },
    noBorder: {
        borderTopWidth: 0,
    },
    sheetText: {
        fontSize: 15,
        color: Theme.colorTextBase,
    },
    disabledText: {
        color: Theme.colorTextDisabled,
    },
    main: {
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
        paddingHorizontal: 15,
    },
    mainInLeft: {
        justifyContent: 'flex-start',
    },
    mainInRight: {
        justifyContent: 'flex-end',
    },
    mainBetween: {
        justifyContent: 'space-between',
    },
    checkWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    sub: {
        marginTop: 4,
        justifyContent: 'center',
        paddingHorizontal: 15,
    },
    subInLeft: {
        justifyContent: 'flex-start',
    },
    icon: {
        marginRight: 18,
    },
    subText: {
        fontSize: 12,
        color: Theme.colorTextSecondary,
    },
    cancel: {
        marginTop: 8,
        alignItems: 'center',
    },
});
export default ActionSheet;
